==> org.eclipse.incquery.uml.source_1.1.0.201512031022.jar: org/eclipse/incquery/uml/derivedfeatures/ConnectorKindMatch.java <==
package org.eclipse.incquery.uml.derivedfeatures;

import java.util.Arrays;
import java.util.List;
import org.eclipse.incquery.runtime.api.IPatternMatch;
import org.eclipse.incquery.runtime.api.impl.BasePatternMatch;
import org.eclipse.incquery.runtime.exception.IncQueryException;
import org.eclipse.incquery.uml.derivedfeatures.util.ConnectorKindQuerySpecification;
import org.eclipse.uml2.uml.Connector;
import org.eclipse.uml2.uml.ConnectorKind;

/**
 * Pattern-specific match representation of the org.eclipse.incquery.uml.derivedfeatures.connectorKind pattern,
 * to be used in conjunction with {@link ConnectorKindMatcher}.
 * 
 * <p>Class fields correspond to parameters of the pattern. Fields with value null are considered unassigned.
 * Each instance is a (possibly partial) substitution of pattern parameters,
 * usable to represent a match of the pattern in the result of a query,
 * or to specify the bound (fixed) input parameters when issuing a query.
 * 
 * @see ConnectorKindMatcher
 * @see ConnectorKindProcessor
 * 
 */
@SuppressWarnings("all")
public abstract class ConnectorKindMatch extends BasePatternMatch {
  private Connector fSelf;
  
  private ConnectorKind fKind;
  
  private static List<String> parameterNames = makeImmutableList("self", "kind");
  
  private ConnectorKindMatch(final Connector pSelf, final ConnectorKind pKind) {
    this.fSelf = pSelf;
    this.fKind = pKind;
  }
  
  @Override
  public Object get(final String parameterName) {
    if ("self".equals(parameterName)) return this.fSelf;
    if ("kind".equals(parameterName)) return this.fKind;
    return null;
  }
  
  public Connector getSelf() {
    return this.fSelf;
  }
  
  public ConnectorKind getKind() {
    return this.fKind;
  }
  
  @Override
  public boolean set(final String parameterName, final Object newValue) {
    if (!isMutable()) throw new java.lang.UnsupportedOperationException();
    if ("self".equals(parameterName) ) {
    	this.fSelf = (org.eclipse.uml2.uml.Connector) newValue;
    	return true;
    }
    if ("kind".equals(parameterName) ) {
    	this.fKind = (org.eclipse.uml2.uml.ConnectorKind) newValue;
    	return true;
    }
    return false;
  }
  
  public void setSelf(final Connector pSelf) {
    if (!isMutable()) throw new java.lang.UnsupportedOperationException();
    this.fSelf = pSelf;
  }
  
  public void setKind(final ConnectorKind pKind) {
    if (!isMutable()) throw new java.lang.UnsupportedOperationException();
    this.fKind = pKind;
  }
  
  @Override
  public String patternName() {
    return "org.eclipse.incquery.uml.derivedfeatures.connectorKind";
  }
  
  @Override
  public List<String> parameterNames() {
    return ConnectorKindMatch.parameterNames;
  }
  
  @Override
  public Object[] toArray() {
    return new Object[]{fSelf, fKind};
  }
  
  @Override
  public ConnectorKindMatch toImmutable() {
    return isMutable() ? newMatch(fSelf, fKind) : this;
  }
  
  @Override
  public String prettyPrint() {
    StringBuilder result = new StringBuilder();
    result.append("\"self\"=" + prettyPrintValue(fSelf) + ", ");
    
    result.append("\"kind\"=" + prettyPrintValue(fKind)
    );
    return result.toString();
  }
  
  @Override
  public int hashCode() {
    final int prime = 31;
    int result = 1;
    result = prime * result + ((fSelf == null) ? 0 : fSelf.hashCode());
    result = prime * result + ((fKind == null) ? 0 : fKind.hashCode());
    return result;
  }
  
  @Override
  public boolean equals(final Object obj) {
    if (this == obj)
    	return true;
    if (!(obj instanceof ConnectorKindMatch)) { // this should be infrequent
    	if (obj == null) {
    		return false;
    	}
    	if (!(obj instanceof IPatternMatch)) {
    		return false;
    	}
    	IPatternMatch otherSig  = (IPatternMatch) obj;
    	if (!specification().equals(otherSig.specification()))
    		return false;
    	return Arrays.deepEquals(toArray(), otherSig.toArray());
    }
    ConnectorKindMatch other = (ConnectorKindMatch) obj;
    if (fSelf == null) {if (other.fSelf != null) return false;}
    else if (!fSelf.equals(other.fSelf)) return false;
    if (fKind == null) {if (other.fKind != null) return false;}
    else if (!fKind.equals(other.fKind)) return false;
    return true;
  }
  
  @Override
  public ConnectorKindQuerySpecification specification() {
    try {
    	return ConnectorKindQuerySpecification.instance();
    } catch (IncQueryException ex) {
     	// This cannot happen, as the match object can only be instantiated if the query specification exists
     	throw new IllegalStateException (ex);
    }
  }
  
  /**
   * Returns an empty, mutable match.
   * Fields of the mutable match can be filled to create a partial match, usable as matcher input.
   * 
   * @return the empty match.
   * 
   */
  public static ConnectorKindMatch newEmptyMatch() {
    return new Mutable(null, null);
  }
  
  /**
   * Returns a mutable (partial) match.
   * Fields of the mutable match can be filled to create a partial match, usable as matcher input.
   * 
   * @param pSelf the fixed value of pattern parameter self, or null if not bound.
   * @param pKind the fixed value of pattern parameter kind, or null if not bound.
   * @return the new, mutable (partial) match object.
   * 
   */
  public static ConnectorKindMatch newMutableMatch(final Connector pSelf, final ConnectorKind pKind) {
    return new Mutable(pSelf, pKind);
  }
  
  /**
   * Returns a new (partial) match.
   * This can be used e.g. to call the matcher with a partial match.
   * <p>The returned match will be immutable. Use {@link #newEmptyMatch()} to obtain a mutable match object.
   * @param pSelf the fixed value of pattern parameter self, or null if not bound.
   * @param pKind the fixed value of pattern parameter kind, or null if not bound.
   * @return the (partial) match object.
   * 
   */
  public static ConnectorKindMatch newMatch(final Connector pSelf, final ConnectorKind pKind) {
    return new Immutable(pSelf, pKind);
  }
  
  private static final class Mutable extends ConnectorKindMatch {
    Mutable(final Connector pSelf, final ConnectorKind pKind) {
      super(pSelf, pKind);
    }
    
    @Override
    public boolean isMutable() {
      return true;
    }
  }
  
  private static final class Immutable extends ConnectorKindMatch {
    Immutable(final Connector pSelf, final ConnectorKind pKind) {
      super(pSelf, pKind);
    }
    
    @Override
    public boolean isMutable() {
      return false;
    }
  }
}

==> org.eclipse.incquery.uml.source_1.2.0.201602080945.jar: org/eclipse/incquery/uml/derivedfeatures/ConnectorKindMatch.java <==
package org.eclipse.incquery.uml.derivedfeatures;

import java.util.Arrays;
import java.util.List;
import org.eclipse.incquery.runtime.api.IPatternMatch;
import org.eclipse.incquery.runtime.api.impl.BasePatternMatch;
import org.eclipse.incquery.runtime.exception.IncQueryException;
import org.eclipse.incquery.uml.derivedfeatures.util.ConnectorKindQuerySpecification;
import org.eclipse.uml2.uml.Connector;
import org.eclipse.uml2.uml.ConnectorKind;

/**
 * Pattern-specific match representation of the org.eclipse.incquery.uml.derivedfeatures.connectorKind pattern,
 * to be used in conjunction with {@link ConnectorKindMatcher}.
 * 
 * <p>Class fields correspond to parameters of the pattern. Fields with value null are considered unassigned.
 * Each instance is a (possibly partial) substitution of pattern parameters,
 * usable to represent a match of the pattern in the result of a query,
 * or to specify the bound (fixed) input parameters when issuing a query.
 * 
 * @see ConnectorKindMatcher
 * @see ConnectorKindProcessor
 * 
 */
@SuppressWarnings("all")
public abstract class ConnectorKindMatch extends BasePatternMatch {
  private Connector fSelf;
  
  private ConnectorKind fKind;
  
  private static List<String> parameterNames = makeImmutableList("self", "kind");
  
  private ConnectorKindMatch(final Connector pSelf, final ConnectorKind pKind) {
    this.fSelf = pSelf;
    this.fKind = pKind;
  }
  
  @Override
  public Object get(final String parameterName) {
    if ("self".equals(parameterName)) return this.fSelf;
    if ("kind".equals(parameterName)) return this.fKind;
    return null;
  }
  
  public Connector getSelf() {
    return this.fSelf;
  }
  
  public ConnectorKind getKind() {
    return this.fKind;
  }
  
  @Override
  public boolean set(final String parameterName, final Object newValue) {
    if (!isMutable()) throw new java.lang.UnsupportedOperationException();
    if ("self".equals(parameterName) ) {
    	this.fSelf = (Connector) newValue;
    	return true;
    }
    if ("kind".equals(parameterName) ) {
    	this.fKind = (ConnectorKind) newValue;
    	return true;
    }
    return false;
  }
  
  public void setSelf(final Connector pSelf) {
    if (!isMutable()) throw new java.lang.UnsupportedOperationException();
    this.fSelf = pSelf;
  }
  
  public void setKind(final ConnectorKind pKind) {
    if (!isMutable()) throw new java.lang.UnsupportedOperationException();
    this.fKind = pKind;
  }
  
  @Override
  public String patternName() {
    return "org.eclipse.incquery.uml.derivedfeatures.connectorKind";
  }
  
  @Override
  public List<String> parameterNames() {
    return ConnectorKindMatch.parameterNames;
  }
  
  @Override
  public Object[] toArray() {
    return new Object[]{fSelf, fKind};
  }
  
  @Override
  public ConnectorKindMatch toImmutable() {
    return isMutable() ? newMatch(fSelf, fKind) : this;
  }
  
  @Override
  public String prettyPrint() {
    StringBuilder result = new StringBuilder();
    result.append("\"self\"=" + prettyPrintValue(fSelf) + ", ");
    
    result.append("\"kind\"=" + prettyPrintValue(fKind)
    );
    return result.toString();
  }
  
  @Override
  public int hashCode() {
    final int prime = 31;
    int result = 1;
    result = prime * result + ((fSelf == null) ? 0 : fSelf.hashCode());
    result = prime * result + ((fKind == null) ? 0 : fKind.hashCode());
    return result;
  }
  
  @Override
  public boolean equals(final Object obj) {
    if (this == obj)
    	return true;
    if (!(obj instanceof ConnectorKindMatch)) { // this should be infrequent
    	if (obj == null) {
    		return false;
    	}
    	if (!(obj instanceof IPatternMatch)) {
    		return false;
    	}
    	IPatternMatch otherSig  = (IPatternMatch) obj;
    	if (!specification().equals(otherSig.specification()))
    		return false;
    	return Arrays.deepEquals(toArray(), otherSig.toArray());
    }
    ConnectorKindMatch other = (ConnectorKindMatch) obj;
    if (fSelf == null) {if (other.fSelf != null) return false;}
    else if (!fSelf.equals(other.fSelf)) return false;
    if (fKind == null) {if (other.fKind != null) return false;}
    else if (!fKind.equals(other.fKind)) return false;
    return true;
  }
  
  @Override
  public ConnectorKindQuerySpecification specification() {
    try {
    	return ConnectorKindQuerySpecification.instance();
    } catch (IncQueryException ex) {
     	// This cannot happen, as the match object can only be instantiated if the query specification exists
     	throw new IllegalStateException (ex);
    }
  }
  
  /**
   * Returns an empty, mutable match.
   * Fields of the mutable match can be filled to create a partial match, usable as matcher input.
   * 
   * @return the empty match.
   * 
   */
  public static ConnectorKindMatch newEmptyMatch() {
    return new Mutable(null, null);
  }
  
  /**
   * Returns a mutable (partial) match.
   * Fields of the mutable match can be filled to create a partial match, usable as matcher input.
   * 
   * @param pSelf the fixed value of pattern parameter self, or null if not bound.
   * @param pKind the fixed value of pattern parameter kind, or null if not bound.
   * @return the new, mutable (partial) match object.
   * 
   */
  public static ConnectorKindMatch newMutableMatch(final Connector pSelf, final ConnectorKind pKind) {
    return new Mutable(pSelf, pKind);
  }
  
  /**
   * Returns a new (partial) match.
   * This can be used e.g. to call the matcher with a partial match.
   * <p>The returned match will be immutable. Use {@link #newEmptyMatch()} to obtain a mutable match object.
   * @param pSelf the fixed value of pattern parameter self, or null if not bound.
   * @param pKind the fixed value of pattern parameter kind, or null if not bound.
   * @return the (partial) match object.
   * 
   */
  public static ConnectorKindMatch newMatch(final Connector pSelf, final ConnectorKind pKind) {
    return new Immutable(pSelf, pKind);
  }
  
  private static final class Mutable extends ConnectorKindMatch {
    Mutable(final Connector pSelf, final ConnectorKind pKind) {
      super(pSelf, pKind);
    }
    
    @Override
    public boolean isMutable() {
      return true;
    }
  }
  
  private static final class Immutable extends ConnectorKindMatch {
    Immutable(final Connector pSelf, final ConnectorKind pKind) {
      super(pSelf, pKind);
    }
    
    @Override
    public boolean isMutable() {
      return false;
    }
  }
}
